module ProductManagement
  class Product < ActiveRecord::Base

    #include ::ProductManagement::ProductPriceCalculator

    belongs_to :company, :class_name => '::CoreModels::PeopleAndCompanies::Company'
    belongs_to :product_type, :class_name => '::ProductManagement::ProductType'
    belongs_to :master_category, :class_name => '::ProductManagement::ProductCategory', :optional => true
    belongs_to :recurring_fee_interval_unit, :class_name => '::CoreModels::Base::Timespan', :optional => true
    belongs_to :currency, :class_name => '::CoreModels::Base::Currency'
    # TODO: belongs_to :status
    belongs_to :tax_class, :class_name => '::CoreModels::Misc::TaxClass'

    belongs_to :image, :class_name => '::AssetManagement::AssetData', :optional => true

    has_many :product_attributes, :class_name => '::ProductManagement::ProductAttribute'
    #has_many :product_options, :class_name => '::ProductManagement::ProductOption'

    #----------------------------------------------------------------------------

    #attr_accessible :company, :gtin, :product_type, :name, :model, :master_category_id
    #attr_accessible :unit_price, :currency, :price_includes_tax
    #attr_accessible :recurring_fee, :recurring_fee_interval_count, :recurring_fee_interval_unit
    #attr_accessible :virtual, :is_free, :is_call_for_price
    #attr_accessible :is_always_free_shipping
    #attr_accessible :status, :status_id, :tax_class, :tax_class_id

    #----------------------------------------------------------------------------

    validates :company, :presence => true
    validates :gtin, :presence => true
    validates :name, :presence => true
    validates :model, :presence => true
    validates :unit_price, :presence => true
    validates :currency, :presence => true

    #---------------------------------------------------------------------------

    def description
      "#{gtin} - #{name} (#{model})"
    end

    def pre_tax_price
      tmp = price_includes_tax ? price_with_tax / (1.0 + (::CoreModels::Misc::VatRate.default.standard_rate/100.0)) : unit_price
      (100 * tmp).round*0.01
    end

    def tax
      tmp = price_includes_tax ? price_with_tax - pre_tax_price : pre_tax_price * (::CoreModels::Misc::VatRate.default.standard_rate/100.0)
      (100 * tmp).round*0.01
    end

    def price_with_tax
      tmp = price_includes_tax ? unit_price : pre_tax_price + tax
      (100 * tmp).round*0.01
    end

    #---------------------------------------------------------------------------

    def to_s
      description
    end
  end
end
